Stirrups: Python 3 dependency injection
==============================================

**Stirrups** uses Python 3 annotations to provide a simple yet flexible
dependency injection framework.

Get It Now
----------

::

    $ pip install -U stirrups

Documentation
-------------

Requirements
------------

-  Python >= 3.8

License
-------

MIT licensed. See the bundled
`LICENSE <https://github.com/cbourget/stirrups/blob/pypi/LICENSE>`__
file for more details.
